// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef BLUEZQT_VERSION_H
#define BLUEZQT_VERSION_H

#define BLUEZQT_VERSION_STRING "5.116.0"
#define BLUEZQT_VERSION_MAJOR 5
#define BLUEZQT_VERSION_MINOR 116
#define BLUEZQT_VERSION_PATCH 0
#define BLUEZQT_VERSION ((5<<16)|(116<<8)|(0))

#endif
